:mod:`kwant.plotter` -- Plotting of systems
===========================================

.. module:: kwant.plotter


Plotting routine
----------------
.. autosummary::
   :toctree: generated/

   plot
   map
   bands

Data-generating functions
-------------------------
.. autosummary::
   :toctree: generated/

   sys_leads_sites
   sys_leads_hoppings
   sys_leads_pos
   sys_leads_hopping_pos
   mask_interpolate
